@@ -26,8 +26,15 @@ def gen_create_sql_query_payload(sql, cache_refresh, cache_ttl, workspace_id):
             mutation createSqlQuery($data: SqlQueryCreateInput!, $where: SqlQueryWhereInput!) {
                 createSqlQuery(data: $data, where: $where) {
                     id
-                    stats
-                    columns
+                    queryStats {
+                        progressPercentage
+                        elapsedTime
+                        completedTasks
+                        totalTasks
+                        peakTotalMemoryReservation
+                        internalNetworkInputDataSize
+                        outputDataSize
+                    }
                     status
                     error
                     location
@@ -56,8 +63,15 @@ def gen_sql_query_payload(sql_query_id):
             query sqlQuery($where: SqlQueryWhereUniqueInput!) {
                 sqlQuery(where: $where) {
                     id
-                    stats
-                    columns
+                    queryStats {
+                        progressPercentage
+                        elapsedTime
+                        completedTasks
+                        totalTasks
+                        peakTotalMemoryReservation
+                        internalNetworkInputDataSize
+                        outputDataSize
+                    }
                     status
                     error
                     location
